" Maintainer	: Nikolai 'pcp' Weibull <da.box@home.se>
" URL		: http://www.pcppopper.org/
" Revised on	: Sun, 26 Aug 2001 15:12:40 +0200

" same as makefile indenting for now.
source <sfile>:p:h/make.vim

" vim: set sw=4 sts=4:
