" Vim filetype plugin file
" Langugage:	Automake
" Maintainer:	Nikolai 'pcp' Weibull <da.box@home.se>
" URL:		http://www.pcppopper.org/
" Revised On:	Tue, 30 Jul 2002 19:49:40 +0200

" same as makefile filetype-plugin for now.
source <sfile>:p:h/make.vim
